KeyProjectResolutionMode

Enum KeyProjectResolutionMode 

#[non_exhaustive]
pub enum KeyProjectResolutionMode { Unspecified, DedicatedKeyProject, ResourceProject, Disabled, UnknownValue(UnknownValue), }
Defines the resolution mode enum for the key project. The KeyProjectResolutionMode determines the mechanism by which AutokeyConfig identifies a key_project at its specific configuration node. This parameter also determines if Autokey can be used within this project or folder.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

Default value. KeyProjectResolutionMode when not specified will act as DEDICATED_KEY_PROJECT.



DedicatedKeyProject

Keys are created in a dedicated project specified by key_project.



ResourceProject

Keys are created in the same project as the resource requesting the key. The key_project must not be set when this mode is used.



Disabled

Disables the AutokeyConfig. When this mode is set, any AutokeyConfig from higher levels in the resource hierarchy are ignored for this resource and its descendants. This setting can be overridden by a more specific configuration at a lower level. For example, if Autokey is disabled on a folder, it can be re-enabled on a sub-folder or project within that folder by setting a different mode (e.g., DEDICATED_KEY_PROJECT or RESOURCE_PROJECT).



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using KeyProjectResolutionMode::value or KeyProjectResolutionMode::name.

Implementations

Source

impl KeyProjectResolutionMode

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.