#[non_exhaustive]pub enum CryptoKeyVersionView {
Unspecified,
Full,
UnknownValue(UnknownValue),
}Expand description
A view for CryptoKeyVersions. Controls the level of detail returned for CryptoKeyVersions in KeyManagementService.ListCryptoKeyVersions and KeyManagementService.ListCryptoKeys.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default view for each CryptoKeyVersion. Does not include the attestation field.
Full
Provides all fields in each CryptoKeyVersion, including the attestation.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CryptoKeyVersionView::value or CryptoKeyVersionView::name.
Implementations