ServiceResolver

Struct ServiceResolver 

#[non_exhaustive]
pub struct ServiceResolver { pub service_directory_service: String, pub endpoint_filter: String, pub hostname: String, pub server_certificates: Vec<Certificate>, /* private fields */ }
A ServiceResolver represents an EKM replica that can be reached within an EkmConnection.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
service_directory_service: String

Required. The resource name of the Service Directory service pointing to an EKM replica, in the format projects/*/locations/*/namespaces/*/services/*.

endpoint_filter: String

Optional. The filter applied to the endpoints of the resolved service. If no filter is specified, all endpoints will be considered. An endpoint will be chosen arbitrarily from the filtered list for each request.

For endpoint filter syntax and examples, see https://cloud.google.com/service-directory/docs/reference/rpc/google.cloud.servicedirectory.v1#resolveservicerequest.

hostname: String

Required. The hostname of the EKM replica used at TLS and HTTP layers.

server_certificates: Vec<Certificate>

Required. A list of leaf server certificates used to authenticate HTTPS connections to the EKM replica. Currently, a maximum of 10 Certificate is supported.

Implementations

Source

impl ServiceResolver

pub fn new() -> Self

pub fn set_service_directory_service<T: Into<String>>(self, v: T) -> Self

Sets the value of service_directory_service.

Example
let x = ServiceResolver::new().set_service_directory_service("example");
pub fn set_endpoint_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of endpoint_filter.

Example
let x = ServiceResolver::new().set_endpoint_filter("example");
pub fn set_hostname<T: Into<String>>(self, v: T) -> Self

Sets the value of hostname.

Example
let x = ServiceResolver::new().set_hostname("example");
pub fn set_server_certificates<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Certificate>,

Sets the value of server_certificates.

Example
use google_cloud_kms_v1::model::Certificate;
let x = ServiceResolver::new()
    .set_server_certificates([
        Certificate::default()/* use setters */,
        Certificate::default()/* use (different) setters */,
    ]);