#[non_exhaustive]pub enum ProtectionLevel {
Unspecified,
Software,
Hsm,
External,
ExternalVpc,
HsmSingleTenant,
UnknownValue(UnknownValue),
}Expand description
ProtectionLevel specifies how cryptographic operations are performed. For more information, see [Protection levels] (https://cloud.google.com/kms/docs/algorithms#protection_levels).
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Not specified.
Software
Crypto operations are performed in software.
Hsm
Crypto operations are performed in a Hardware Security Module.
External
Crypto operations are performed by an external key manager.
ExternalVpc
Crypto operations are performed in an EKM-over-VPC backend.
HsmSingleTenant
Crypto operations are performed in a single-tenant HSM.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ProtectionLevel::value or ProtectionLevel::name.
Implementations