AsymmetricDecryptRequest

Struct AsymmetricDecryptRequest 

#[non_exhaustive]
pub struct AsymmetricDecryptRequest { pub name: String, pub ciphertext: Bytes, pub ciphertext_crc32c: Option<Int64Value>, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The resource name of the CryptoKeyVersion to use for decryption.

ciphertext: Bytes

Required. The data encrypted with the named CryptoKeyVersion’s public key using OAEP.

ciphertext_crc32c: Option<Int64Value>

Optional. An optional CRC32C checksum of the AsymmetricDecryptRequest.ciphertext. If specified, KeyManagementService will verify the integrity of the received AsymmetricDecryptRequest.ciphertext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(AsymmetricDecryptRequest.ciphertext) is equal to AsymmetricDecryptRequest.ciphertext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

Implementations

Source

impl AsymmetricDecryptRequest

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = AsymmetricDecryptRequest::new().set_name("example");
pub fn set_ciphertext<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of ciphertext.

Example
let x = AsymmetricDecryptRequest::new().set_ciphertext(bytes::Bytes::from_static(b"example"));
pub fn set_ciphertext_crc32c<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of ciphertext_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricDecryptRequest::new().set_ciphertext_crc32c(Int64Value::default()/* use setters */);
pub fn set_or_clear_ciphertext_crc32c<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of ciphertext_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricDecryptRequest::new().set_or_clear_ciphertext_crc32c(Some(Int64Value::default()/* use setters */));
let x = AsymmetricDecryptRequest::new().set_or_clear_ciphertext_crc32c(None::<Int64Value>);