AsymmetricSignRequest

Struct AsymmetricSignRequest 

#[non_exhaustive]
pub struct AsymmetricSignRequest { pub name: String, pub digest: Option<Digest>, pub digest_crc32c: Option<Int64Value>, pub data: Bytes, pub data_crc32c: Option<Int64Value>, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The resource name of the CryptoKeyVersion to use for signing.

digest: Option<Digest>

Optional. The digest of the data to sign. The digest must be produced with the same digest algorithm as specified by the key version’s algorithm.

This field may not be supplied if AsymmetricSignRequest.data is supplied.

digest_crc32c: Option<Int64Value>

Optional. An optional CRC32C checksum of the AsymmetricSignRequest.digest. If specified, KeyManagementService will verify the integrity of the received AsymmetricSignRequest.digest using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(AsymmetricSignRequest.digest) is equal to AsymmetricSignRequest.digest_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

data: Bytes

Optional. The data to sign. It can’t be supplied if AsymmetricSignRequest.digest is supplied.

data_crc32c: Option<Int64Value>

Optional. An optional CRC32C checksum of the AsymmetricSignRequest.data. If specified, KeyManagementService will verify the integrity of the received AsymmetricSignRequest.data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(AsymmetricSignRequest.data) is equal to AsymmetricSignRequest.data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

Implementations

Source

impl AsymmetricSignRequest

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = AsymmetricSignRequest::new().set_name("example");
pub fn set_digest<T>(self, v: T) -> Self
where T: Into<Digest>,

Sets the value of digest.

Example
use google_cloud_kms_v1::model::Digest;
let x = AsymmetricSignRequest::new().set_digest(Digest::default()/* use setters */);
pub fn set_or_clear_digest<T>(self, v: Option<T>) -> Self
where T: Into<Digest>,

Sets or clears the value of digest.

Example
use google_cloud_kms_v1::model::Digest;
let x = AsymmetricSignRequest::new().set_or_clear_digest(Some(Digest::default()/* use setters */));
let x = AsymmetricSignRequest::new().set_or_clear_digest(None::<Digest>);
pub fn set_digest_crc32c<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of digest_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricSignRequest::new().set_digest_crc32c(Int64Value::default()/* use setters */);
pub fn set_or_clear_digest_crc32c<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of digest_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricSignRequest::new().set_or_clear_digest_crc32c(Some(Int64Value::default()/* use setters */));
let x = AsymmetricSignRequest::new().set_or_clear_digest_crc32c(None::<Int64Value>);
pub fn set_data<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of data.

Example
let x = AsymmetricSignRequest::new().set_data(bytes::Bytes::from_static(b"example"));
pub fn set_data_crc32c<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of data_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricSignRequest::new().set_data_crc32c(Int64Value::default()/* use setters */);
pub fn set_or_clear_data_crc32c<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of data_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricSignRequest::new().set_or_clear_data_crc32c(Some(Int64Value::default()/* use setters */));
let x = AsymmetricSignRequest::new().set_or_clear_data_crc32c(None::<Int64Value>);