AsymmetricSignResponse

Struct AsymmetricSignResponse 

#[non_exhaustive]
pub struct AsymmetricSignResponse { pub signature: Bytes, pub signature_crc32c: Option<Int64Value>, pub verified_digest_crc32c: bool, pub name: String, pub verified_data_crc32c: bool, pub protection_level: ProtectionLevel, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
signature: Bytes

The created signature.

signature_crc32c: Option<Int64Value>

Integrity verification field. A CRC32C checksum of the returned AsymmetricSignResponse.signature. An integrity check of AsymmetricSignResponse.signature can be performed by computing the CRC32C checksum of AsymmetricSignResponse.signature and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

verified_digest_crc32c: bool

Integrity verification field. A flag indicating whether AsymmetricSignRequest.digest_crc32c was received by KeyManagementService and used for the integrity verification of the digest. A false value of this field indicates either that AsymmetricSignRequest.digest_crc32c was left unset or that it was not delivered to KeyManagementService. If you’ve set AsymmetricSignRequest.digest_crc32c but this field is still false, discard the response and perform a limited number of retries.

name: String

The resource name of the CryptoKeyVersion used for signing. Check this field to verify that the intended resource was used for signing.

verified_data_crc32c: bool

Integrity verification field. A flag indicating whether AsymmetricSignRequest.data_crc32c was received by KeyManagementService and used for the integrity verification of the data. A false value of this field indicates either that AsymmetricSignRequest.data_crc32c was left unset or that it was not delivered to KeyManagementService. If you’ve set AsymmetricSignRequest.data_crc32c but this field is still false, discard the response and perform a limited number of retries.

protection_level: ProtectionLevel

The ProtectionLevel of the CryptoKeyVersion used for signing.

Implementations

Source

impl AsymmetricSignResponse

pub fn new() -> Self

pub fn set_signature<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of signature.

Example
let x = AsymmetricSignResponse::new().set_signature(bytes::Bytes::from_static(b"example"));
pub fn set_signature_crc32c<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of signature_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricSignResponse::new().set_signature_crc32c(Int64Value::default()/* use setters */);
pub fn set_or_clear_signature_crc32c<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of signature_crc32c.

Example
use wkt::Int64Value;
let x = AsymmetricSignResponse::new().set_or_clear_signature_crc32c(Some(Int64Value::default()/* use setters */));
let x = AsymmetricSignResponse::new().set_or_clear_signature_crc32c(None::<Int64Value>);
pub fn set_verified_digest_crc32c<T: Into<bool>>(self, v: T) -> Self

Sets the value of verified_digest_crc32c.

Example
let x = AsymmetricSignResponse::new().set_verified_digest_crc32c(true);
pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = AsymmetricSignResponse::new().set_name("example");
pub fn set_verified_data_crc32c<T: Into<bool>>(self, v: T) -> Self

Sets the value of verified_data_crc32c.

Example
let x = AsymmetricSignResponse::new().set_verified_data_crc32c(true);
pub fn set_protection_level<T: Into<ProtectionLevel>>(self, v: T) -> Self

Sets the value of protection_level.

Example
use google_cloud_kms_v1::model::ProtectionLevel;
let x0 = AsymmetricSignResponse::new().set_protection_level(ProtectionLevel::Software);
let x1 = AsymmetricSignResponse::new().set_protection_level(ProtectionLevel::Hsm);
let x2 = AsymmetricSignResponse::new().set_protection_level(ProtectionLevel::External);