#[non_exhaustive]pub struct CreateKeyHandleRequest {
pub parent: String,
pub key_handle_id: String,
pub key_handle: Option<KeyHandle>,
/* private fields */
}Expand description
Request message for Autokey.CreateKeyHandle.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Name of the resource project and location to create the
KeyHandle in, e.g.
projects/{PROJECT_ID}/locations/{LOCATION}.
key_handle_id: StringOptional. Id of the KeyHandle. Must be unique to the resource project and location. If not provided by the caller, a new UUID is used.
key_handle: Option<KeyHandle>Required. KeyHandle to create.
Implementations
Sourceimpl CreateKeyHandleRequest
impl CreateKeyHandleRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_key_handle_id<T: Into<String>>(self, v: T) -> Self
pub fn set_key_handle_id<T: Into<String>>(self, v: T) -> Self
Sets the value of key_handle_id.
Example
ⓘ
let x = CreateKeyHandleRequest::new().set_key_handle_id("example");Sourcepub fn set_key_handle<T>(self, v: T) -> Self
pub fn set_key_handle<T>(self, v: T) -> Self
Sets the value of key_handle.
Example
ⓘ
use google_cloud_kms_v1::model::KeyHandle;
let x = CreateKeyHandleRequest::new().set_key_handle(KeyHandle::default()/* use setters */);Sourcepub fn set_or_clear_key_handle<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_key_handle<T>(self, v: Option<T>) -> Self
Sets or clears the value of key_handle.
Example
ⓘ
use google_cloud_kms_v1::model::KeyHandle;
let x = CreateKeyHandleRequest::new().set_or_clear_key_handle(Some(KeyHandle::default()/* use setters */));
let x = CreateKeyHandleRequest::new().set_or_clear_key_handle(None::<KeyHandle>);Trait Implementations
Sourceimpl Clone for CreateKeyHandleRequest
impl Clone for CreateKeyHandleRequest
Sourcefn clone(&self) -> CreateKeyHandleRequest
fn clone(&self) -> CreateKeyHandleRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateKeyHandleRequest
impl Debug for CreateKeyHandleRequest
Sourceimpl Default for CreateKeyHandleRequest
impl Default for CreateKeyHandleRequest
Sourcefn default() -> CreateKeyHandleRequest
fn default() -> CreateKeyHandleRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateKeyHandleRequest
impl Message for CreateKeyHandleRequest
Sourceimpl PartialEq for CreateKeyHandleRequest
impl PartialEq for CreateKeyHandleRequest
impl StructuralPartialEq for CreateKeyHandleRequest