#[non_exhaustive]pub struct CreateSingleTenantHsmInstanceProposalRequest {
pub parent: String,
pub single_tenant_hsm_instance_proposal_id: String,
pub single_tenant_hsm_instance_proposal: Option<SingleTenantHsmInstanceProposal>,
/* private fields */
}Expand description
Request message for HsmManagement.CreateSingleTenantHsmInstanceProposal.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the SingleTenantHsmInstance associated with the SingleTenantHsmInstanceProposals.
single_tenant_hsm_instance_proposal_id: StringOptional. It must be unique within a location and match the regular
expression [a-zA-Z0-9_-]{1,63}.
single_tenant_hsm_instance_proposal: Option<SingleTenantHsmInstanceProposal>Required. The SingleTenantHsmInstanceProposal to create.
Implementations
Sourceimpl CreateSingleTenantHsmInstanceProposalRequest
impl CreateSingleTenantHsmInstanceProposalRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_single_tenant_hsm_instance_proposal_id<T: Into<String>>(
self,
v: T,
) -> Self
pub fn set_single_tenant_hsm_instance_proposal_id<T: Into<String>>( self, v: T, ) -> Self
Sets the value of single_tenant_hsm_instance_proposal_id.
Example
ⓘ
let x = CreateSingleTenantHsmInstanceProposalRequest::new().set_single_tenant_hsm_instance_proposal_id("example");Sourcepub fn set_single_tenant_hsm_instance_proposal<T>(self, v: T) -> Selfwhere
T: Into<SingleTenantHsmInstanceProposal>,
pub fn set_single_tenant_hsm_instance_proposal<T>(self, v: T) -> Selfwhere
T: Into<SingleTenantHsmInstanceProposal>,
Sets the value of single_tenant_hsm_instance_proposal.
Example
ⓘ
use google_cloud_kms_v1::model::SingleTenantHsmInstanceProposal;
let x = CreateSingleTenantHsmInstanceProposalRequest::new().set_single_tenant_hsm_instance_proposal(SingleTenantHsmInstanceProposal::default()/* use setters */);Sourcepub fn set_or_clear_single_tenant_hsm_instance_proposal<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<SingleTenantHsmInstanceProposal>,
pub fn set_or_clear_single_tenant_hsm_instance_proposal<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<SingleTenantHsmInstanceProposal>,
Sets or clears the value of single_tenant_hsm_instance_proposal.
Example
ⓘ
use google_cloud_kms_v1::model::SingleTenantHsmInstanceProposal;
let x = CreateSingleTenantHsmInstanceProposalRequest::new().set_or_clear_single_tenant_hsm_instance_proposal(Some(SingleTenantHsmInstanceProposal::default()/* use setters */));
let x = CreateSingleTenantHsmInstanceProposalRequest::new().set_or_clear_single_tenant_hsm_instance_proposal(None::<SingleTenantHsmInstanceProposal>);Trait Implementations
Sourceimpl Clone for CreateSingleTenantHsmInstanceProposalRequest
impl Clone for CreateSingleTenantHsmInstanceProposalRequest
Sourcefn clone(&self) -> CreateSingleTenantHsmInstanceProposalRequest
fn clone(&self) -> CreateSingleTenantHsmInstanceProposalRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateSingleTenantHsmInstanceProposalRequest
impl Default for CreateSingleTenantHsmInstanceProposalRequest
Sourcefn default() -> CreateSingleTenantHsmInstanceProposalRequest
fn default() -> CreateSingleTenantHsmInstanceProposalRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateSingleTenantHsmInstanceProposalRequest
impl PartialEq for CreateSingleTenantHsmInstanceProposalRequest
Sourcefn eq(&self, other: &CreateSingleTenantHsmInstanceProposalRequest) -> bool
fn eq(&self, other: &CreateSingleTenantHsmInstanceProposalRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateSingleTenantHsmInstanceProposalRequest