#[non_exhaustive]pub struct DecryptRequest {
pub name: String,
pub ciphertext: Bytes,
pub additional_authenticated_data: Bytes,
pub ciphertext_crc32c: Option<Int64Value>,
pub additional_authenticated_data_crc32c: Option<Int64Value>,
/* private fields */
}Expand description
Request message for KeyManagementService.Decrypt.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the CryptoKey to use for decryption. The server will choose the appropriate version.
ciphertext: BytesRequired. The encrypted data originally returned in EncryptResponse.ciphertext.
additional_authenticated_data: BytesOptional. Optional data that must match the data originally supplied in EncryptRequest.additional_authenticated_data.
ciphertext_crc32c: Option<Int64Value>Optional. An optional CRC32C checksum of the DecryptRequest.ciphertext. If specified, KeyManagementService will verify the integrity of the received DecryptRequest.ciphertext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(DecryptRequest.ciphertext) is equal to DecryptRequest.ciphertext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.
additional_authenticated_data_crc32c: Option<Int64Value>Optional. An optional CRC32C checksum of the DecryptRequest.additional_authenticated_data. If specified, KeyManagementService will verify the integrity of the received DecryptRequest.additional_authenticated_data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(DecryptRequest.additional_authenticated_data) is equal to DecryptRequest.additional_authenticated_data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.
Implementations
Sourceimpl DecryptRequest
impl DecryptRequest
Sourcepub fn set_ciphertext<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_ciphertext<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of ciphertext.
Example
let x = DecryptRequest::new().set_ciphertext(bytes::Bytes::from_static(b"example"));Sourcepub fn set_additional_authenticated_data<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_additional_authenticated_data<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of additional_authenticated_data.
Example
let x = DecryptRequest::new().set_additional_authenticated_data(bytes::Bytes::from_static(b"example"));Sourcepub fn set_ciphertext_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_ciphertext_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of ciphertext_crc32c.
Example
use wkt::Int64Value;
let x = DecryptRequest::new().set_ciphertext_crc32c(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_ciphertext_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_ciphertext_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of ciphertext_crc32c.
Example
use wkt::Int64Value;
let x = DecryptRequest::new().set_or_clear_ciphertext_crc32c(Some(Int64Value::default()/* use setters */));
let x = DecryptRequest::new().set_or_clear_ciphertext_crc32c(None::<Int64Value>);Sourcepub fn set_additional_authenticated_data_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_additional_authenticated_data_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of additional_authenticated_data_crc32c.
Example
use wkt::Int64Value;
let x = DecryptRequest::new().set_additional_authenticated_data_crc32c(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_additional_authenticated_data_crc32c<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_additional_authenticated_data_crc32c<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of additional_authenticated_data_crc32c.
Example
use wkt::Int64Value;
let x = DecryptRequest::new().set_or_clear_additional_authenticated_data_crc32c(Some(Int64Value::default()/* use setters */));
let x = DecryptRequest::new().set_or_clear_additional_authenticated_data_crc32c(None::<Int64Value>);Trait Implementations
Sourceimpl Clone for DecryptRequest
impl Clone for DecryptRequest
Sourcefn clone(&self) -> DecryptRequest
fn clone(&self) -> DecryptRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DecryptRequest
impl Debug for DecryptRequest
Sourceimpl Default for DecryptRequest
impl Default for DecryptRequest
Sourcefn default() -> DecryptRequest
fn default() -> DecryptRequest
Sourceimpl Message for DecryptRequest
impl Message for DecryptRequest
Sourceimpl PartialEq for DecryptRequest
impl PartialEq for DecryptRequest
impl StructuralPartialEq for DecryptRequest