#[non_exhaustive]pub struct EkmConfig {
pub name: String,
pub default_ekm_connection: String,
/* private fields */
}Expand description
An EkmConfig is a singleton resource that represents configuration parameters that apply to all CryptoKeys and CryptoKeyVersions with a ProtectionLevel of EXTERNAL_VPC in a given project and location.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name for the
EkmConfig in the format
projects/*/locations/*/ekmConfig.
default_ekm_connection: StringOptional. Resource name of the default EkmConnection. Setting this field to the empty string removes the default.
Implementations