#[non_exhaustive]pub struct EkmConnection {
pub name: String,
pub create_time: Option<Timestamp>,
pub service_resolvers: Vec<ServiceResolver>,
pub etag: String,
pub key_management_mode: KeyManagementMode,
pub crypto_space_path: String,
/* private fields */
}Expand description
An EkmConnection represents an individual EKM connection. It can be used for creating CryptoKeys and CryptoKeyVersions with a ProtectionLevel of EXTERNAL_VPC, as well as performing cryptographic operations using keys created within the EkmConnection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name for the
EkmConnection in the format
projects/*/locations/*/ekmConnections/*.
create_time: Option<Timestamp>Output only. The time at which the EkmConnection was created.
service_resolvers: Vec<ServiceResolver>Optional. A list of ServiceResolvers where the EKM can be reached. There should be one ServiceResolver per EKM replica. Currently, only a single ServiceResolver is supported.
etag: StringOptional. Etag of the currently stored EkmConnection.
key_management_mode: KeyManagementModeOptional. Describes who can perform control plane operations on the EKM. If unset, this defaults to MANUAL.
crypto_space_path: StringOptional. Identifies the EKM Crypto Space that this EkmConnection maps to. Note: This field is required if KeyManagementMode is CLOUD_KMS.
Implementations
Sourceimpl EkmConnection
impl EkmConnection
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = EkmConnection::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = EkmConnection::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = EkmConnection::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_service_resolvers<T, V>(self, v: T) -> Self
pub fn set_service_resolvers<T, V>(self, v: T) -> Self
Sets the value of service_resolvers.
Example
use google_cloud_kms_v1::model::ekm_connection::ServiceResolver;
let x = EkmConnection::new()
.set_service_resolvers([
ServiceResolver::default()/* use setters */,
ServiceResolver::default()/* use (different) setters */,
]);Sourcepub fn set_key_management_mode<T: Into<KeyManagementMode>>(self, v: T) -> Self
pub fn set_key_management_mode<T: Into<KeyManagementMode>>(self, v: T) -> Self
Sets the value of key_management_mode.
Example
use google_cloud_kms_v1::model::ekm_connection::KeyManagementMode;
let x0 = EkmConnection::new().set_key_management_mode(KeyManagementMode::Manual);
let x1 = EkmConnection::new().set_key_management_mode(KeyManagementMode::CloudKms);Sourcepub fn set_crypto_space_path<T: Into<String>>(self, v: T) -> Self
pub fn set_crypto_space_path<T: Into<String>>(self, v: T) -> Self
Sets the value of crypto_space_path.
Example
let x = EkmConnection::new().set_crypto_space_path("example");Trait Implementations
Sourceimpl Clone for EkmConnection
impl Clone for EkmConnection
Sourcefn clone(&self) -> EkmConnection
fn clone(&self) -> EkmConnection
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more