#[non_exhaustive]pub struct EncryptRequest {
pub name: String,
pub plaintext: Bytes,
pub additional_authenticated_data: Bytes,
pub plaintext_crc32c: Option<Int64Value>,
pub additional_authenticated_data_crc32c: Option<Int64Value>,
/* private fields */
}Expand description
Request message for KeyManagementService.Encrypt.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the CryptoKey or CryptoKeyVersion to use for encryption.
If a CryptoKey is specified, the server will use its primary version.
plaintext: BytesRequired. The data to encrypt. Must be no larger than 64KiB.
The maximum size depends on the key version’s protection_level. For SOFTWARE, EXTERNAL, and EXTERNAL_VPC keys, the plaintext must be no larger than 64KiB. For HSM keys, the combined length of the plaintext and additional_authenticated_data fields must be no larger than 8KiB.
additional_authenticated_data: BytesOptional. Optional data that, if specified, must also be provided during decryption through DecryptRequest.additional_authenticated_data.
The maximum size depends on the key version’s protection_level. For SOFTWARE, EXTERNAL, and EXTERNAL_VPC keys the AAD must be no larger than 64KiB. For HSM keys, the combined length of the plaintext and additional_authenticated_data fields must be no larger than 8KiB.
plaintext_crc32c: Option<Int64Value>Optional. An optional CRC32C checksum of the EncryptRequest.plaintext. If specified, KeyManagementService will verify the integrity of the received EncryptRequest.plaintext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(EncryptRequest.plaintext) is equal to EncryptRequest.plaintext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.
additional_authenticated_data_crc32c: Option<Int64Value>Optional. An optional CRC32C checksum of the EncryptRequest.additional_authenticated_data. If specified, KeyManagementService will verify the integrity of the received EncryptRequest.additional_authenticated_data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(EncryptRequest.additional_authenticated_data) is equal to EncryptRequest.additional_authenticated_data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.
Implementations
Sourceimpl EncryptRequest
impl EncryptRequest
Sourcepub fn set_plaintext<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_plaintext<T: Into<Bytes>>(self, v: T) -> Self
Sourcepub fn set_additional_authenticated_data<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_additional_authenticated_data<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of additional_authenticated_data.
Example
let x = EncryptRequest::new().set_additional_authenticated_data(bytes::Bytes::from_static(b"example"));Sourcepub fn set_plaintext_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_plaintext_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of plaintext_crc32c.
Example
use wkt::Int64Value;
let x = EncryptRequest::new().set_plaintext_crc32c(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_plaintext_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_plaintext_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of plaintext_crc32c.
Example
use wkt::Int64Value;
let x = EncryptRequest::new().set_or_clear_plaintext_crc32c(Some(Int64Value::default()/* use setters */));
let x = EncryptRequest::new().set_or_clear_plaintext_crc32c(None::<Int64Value>);Sourcepub fn set_additional_authenticated_data_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_additional_authenticated_data_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of additional_authenticated_data_crc32c.
Example
use wkt::Int64Value;
let x = EncryptRequest::new().set_additional_authenticated_data_crc32c(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_additional_authenticated_data_crc32c<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_additional_authenticated_data_crc32c<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of additional_authenticated_data_crc32c.
Example
use wkt::Int64Value;
let x = EncryptRequest::new().set_or_clear_additional_authenticated_data_crc32c(Some(Int64Value::default()/* use setters */));
let x = EncryptRequest::new().set_or_clear_additional_authenticated_data_crc32c(None::<Int64Value>);Trait Implementations
Sourceimpl Clone for EncryptRequest
impl Clone for EncryptRequest
Sourcefn clone(&self) -> EncryptRequest
fn clone(&self) -> EncryptRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EncryptRequest
impl Debug for EncryptRequest
Sourceimpl Default for EncryptRequest
impl Default for EncryptRequest
Sourcefn default() -> EncryptRequest
fn default() -> EncryptRequest
Sourceimpl Message for EncryptRequest
impl Message for EncryptRequest
Sourceimpl PartialEq for EncryptRequest
impl PartialEq for EncryptRequest
impl StructuralPartialEq for EncryptRequest