ExportTrustedKeyWrappedCryptoKeyVersionResponse

Struct ExportTrustedKeyWrappedCryptoKeyVersionResponse 

#[non_exhaustive]
pub struct ExportTrustedKeyWrappedCryptoKeyVersionResponse { pub wrapped_key: Bytes, pub wrapped_key_crc32c: Option<Int64Value>, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
wrapped_key: Bytes

The wrapped key material.

wrapped_key_crc32c: Option<Int64Value>

Integrity verification field. A CRC32C checksum of the returned ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key. An integrity check of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key can be performed by computing the CRC32C checksum of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.

Implementations

Source

impl ExportTrustedKeyWrappedCryptoKeyVersionResponse

pub fn new() -> Self

Creates a new default instance.

pub fn set_wrapped_key<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of wrapped_key.

Example
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_wrapped_key(bytes::Bytes::from_static(b"example"));
pub fn set_wrapped_key_crc32c<T>(self, v: T) -> Self
where T: Into<Int64Value>,

Sets the value of wrapped_key_crc32c.

Example
use wkt::Int64Value;
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_wrapped_key_crc32c(Int64Value::default()/* use setters */);
pub fn set_or_clear_wrapped_key_crc32c<T>(self, v: Option<T>) -> Self
where T: Into<Int64Value>,

Sets or clears the value of wrapped_key_crc32c.

Example
use wkt::Int64Value;
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_or_clear_wrapped_key_crc32c(Some(Int64Value::default()/* use setters */));
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_or_clear_wrapped_key_crc32c(None::<Int64Value>);