ImportTrustedKeyWrappedCryptoKeyVersionRequest

Struct ImportTrustedKeyWrappedCryptoKeyVersionRequest 

#[non_exhaustive]
pub struct ImportTrustedKeyWrappedCryptoKeyVersionRequest { pub parent: String, pub importing_key: String, pub crypto_key_version: String, pub wrapped_key: Bytes, pub algorithm: CryptoKeyVersionAlgorithm, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The name of the CryptoKey to be imported into.

importing_key: String

Required. Required - the CKV of the trusted key used to import. This can be the name of a CryptoKeyVersion or a CryptoKey.

crypto_key_version: String

Optional. The optional name of an existing CryptoKeyVersion to target for an import operation. If this field is not present, a new CryptoKeyVersion containing the supplied key material is created.

If this field is present, the supplied key material is imported into the existing CryptoKeyVersion. To import into an existing CryptoKeyVersion, the CryptoKeyVersion must be a child of ImportTrustedKeyWrappedCryptoKeyVersionRequest.parent, have been previously created via ImportTrustedKeyWrappedCryptoKeyVersion, and be in DESTROYED or IMPORT_FAILED state. The key material and algorithm must match the previous CryptoKeyVersion exactly if the CryptoKeyVersion has ever contained key material

wrapped_key: Bytes

Required. The target key pre-wrapped on premises.

algorithm: CryptoKeyVersionAlgorithm

Required. Required - The algorithm of the key being imported. This does not need to match the version_template of the CryptoKey this version imports into.

Implementations

Source

impl ImportTrustedKeyWrappedCryptoKeyVersionRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_parent("example");
pub fn set_importing_key<T: Into<String>>(self, v: T) -> Self

Sets the value of importing_key.

Example
let x = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_importing_key("example");
pub fn set_crypto_key_version<T: Into<String>>(self, v: T) -> Self

Sets the value of crypto_key_version.

Example
let x = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_crypto_key_version("example");
pub fn set_wrapped_key<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of wrapped_key.

Example
let x = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_wrapped_key(bytes::Bytes::from_static(b"example"));
pub fn set_algorithm<T: Into<CryptoKeyVersionAlgorithm>>(self, v: T) -> Self

Sets the value of algorithm.

Example
use google_cloud_kms_v1::model::crypto_key_version::CryptoKeyVersionAlgorithm;
let x0 = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_algorithm(CryptoKeyVersionAlgorithm::GoogleSymmetricEncryption);
let x1 = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_algorithm(CryptoKeyVersionAlgorithm::Aes128Gcm);
let x2 = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_algorithm(CryptoKeyVersionAlgorithm::Aes256Gcm);