#[non_exhaustive]pub struct ListCryptoKeyVersionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub view: CryptoKeyVersionView,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request message for KeyManagementService.ListCryptoKeyVersions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the
CryptoKey to list, in the format
projects/*/locations/*/keyRings/*/cryptoKeys/*.
page_size: i32Optional. Optional limit on the number of CryptoKeyVersions to include in the response. Further CryptoKeyVersions can subsequently be obtained by including the ListCryptoKeyVersionsResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.
page_token: StringOptional. Optional pagination token, returned earlier via ListCryptoKeyVersionsResponse.next_page_token.
view: CryptoKeyVersionViewThe fields to include in the response.
filter: StringOptional. Only include resources that match the filter in the response. For more information, see Sorting and filtering list results.
order_by: StringOptional. Specify how the results should be sorted. If not specified, the results will be sorted in the default order. For more information, see Sorting and filtering list results.
Implementations
Sourceimpl ListCryptoKeyVersionsRequest
impl ListCryptoKeyVersionsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListCryptoKeyVersionsRequest::new().set_page_token("example");Sourcepub fn set_view<T: Into<CryptoKeyVersionView>>(self, v: T) -> Self
pub fn set_view<T: Into<CryptoKeyVersionView>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self