ListCryptoKeysRequest

Struct ListCryptoKeysRequest 

#[non_exhaustive]
pub struct ListCryptoKeysRequest { pub parent: String, pub page_size: i32, pub page_token: String, pub version_view: CryptoKeyVersionView, pub filter: String, pub order_by: String, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The resource name of the KeyRing to list, in the format projects/*/locations/*/keyRings/*.

page_size: i32

Optional. Optional limit on the number of CryptoKeys to include in the response. Further CryptoKeys can subsequently be obtained by including the ListCryptoKeysResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.

page_token: String

Optional. Optional pagination token, returned earlier via ListCryptoKeysResponse.next_page_token.

version_view: CryptoKeyVersionView

The fields of the primary version to include in the response.

filter: String

Optional. Only include resources that match the filter in the response. For more information, see Sorting and filtering list results.

order_by: String

Optional. Specify how the results should be sorted. If not specified, the results will be sorted in the default order. For more information, see Sorting and filtering list results.

Implementations

Source

impl ListCryptoKeysRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListCryptoKeysRequest::new().set_parent("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListCryptoKeysRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListCryptoKeysRequest::new().set_page_token("example");
pub fn set_version_view<T: Into<CryptoKeyVersionView>>(self, v: T) -> Self

Sets the value of version_view.

Example
use google_cloud_kms_v1::model::crypto_key_version::CryptoKeyVersionView;
let x0 = ListCryptoKeysRequest::new().set_version_view(CryptoKeyVersionView::Full);
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListCryptoKeysRequest::new().set_filter("example");
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self

Sets the value of order_by.

Example
let x = ListCryptoKeysRequest::new().set_order_by("example");