#[non_exhaustive]pub struct ListKeyHandlesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for Autokey.ListKeyHandles.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Name of the resource project and location from which to list
KeyHandles, e.g.
projects/{PROJECT_ID}/locations/{LOCATION}.
page_size: i32Optional. Optional limit on the number of KeyHandles to include in the response. The service may return fewer than this value. Further KeyHandles can subsequently be obtained by including the ListKeyHandlesResponse.next_page_token in a subsequent request. If unspecified, at most 100 KeyHandles will be returned.
page_token: StringOptional. Optional pagination token, returned earlier via ListKeyHandlesResponse.next_page_token.
filter: StringOptional. Filter to apply when listing
KeyHandles, e.g.
resource_type_selector="{SERVICE}.googleapis.com/{TYPE}".
Implementations
Sourceimpl ListKeyHandlesRequest
impl ListKeyHandlesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListKeyHandlesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListKeyHandlesRequest
impl Clone for ListKeyHandlesRequest
Sourcefn clone(&self) -> ListKeyHandlesRequest
fn clone(&self) -> ListKeyHandlesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListKeyHandlesRequest
impl Debug for ListKeyHandlesRequest
Sourceimpl Default for ListKeyHandlesRequest
impl Default for ListKeyHandlesRequest
Sourcefn default() -> ListKeyHandlesRequest
fn default() -> ListKeyHandlesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListKeyHandlesRequest
impl Message for ListKeyHandlesRequest
Sourceimpl PartialEq for ListKeyHandlesRequest
impl PartialEq for ListKeyHandlesRequest
impl StructuralPartialEq for ListKeyHandlesRequest