#[non_exhaustive]pub struct MacVerifyRequest {
pub name: String,
pub data: Bytes,
pub data_crc32c: Option<Int64Value>,
pub mac: Bytes,
pub mac_crc32c: Option<Int64Value>,
/* private fields */
}Expand description
Request message for KeyManagementService.MacVerify.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the CryptoKeyVersion to use for verification.
data: BytesRequired. The data used previously as a MacSignRequest.data to generate the MAC tag.
data_crc32c: Option<Int64Value>Optional. An optional CRC32C checksum of the MacVerifyRequest.data. If specified, KeyManagementService will verify the integrity of the received MacVerifyRequest.data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(MacVerifyRequest.data) is equal to MacVerifyRequest.data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.
mac: BytesRequired. The signature to verify.
mac_crc32c: Option<Int64Value>Optional. An optional CRC32C checksum of the MacVerifyRequest.mac. If specified, KeyManagementService will verify the integrity of the received MacVerifyRequest.mac using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(MacVerifyRequest.mac) is equal to MacVerifyRequest.mac_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.
Implementations
Sourceimpl MacVerifyRequest
impl MacVerifyRequest
pub fn new() -> Self
Sourcepub fn set_data_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_data_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of data_crc32c.
Example
use wkt::Int64Value;
let x = MacVerifyRequest::new().set_data_crc32c(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_data_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_data_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of data_crc32c.
Example
use wkt::Int64Value;
let x = MacVerifyRequest::new().set_or_clear_data_crc32c(Some(Int64Value::default()/* use setters */));
let x = MacVerifyRequest::new().set_or_clear_data_crc32c(None::<Int64Value>);Sourcepub fn set_mac_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_mac_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of mac_crc32c.
Example
use wkt::Int64Value;
let x = MacVerifyRequest::new().set_mac_crc32c(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_mac_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_mac_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of mac_crc32c.
Example
use wkt::Int64Value;
let x = MacVerifyRequest::new().set_or_clear_mac_crc32c(Some(Int64Value::default()/* use setters */));
let x = MacVerifyRequest::new().set_or_clear_mac_crc32c(None::<Int64Value>);Trait Implementations
Sourceimpl Clone for MacVerifyRequest
impl Clone for MacVerifyRequest
Sourcefn clone(&self) -> MacVerifyRequest
fn clone(&self) -> MacVerifyRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more