#[non_exhaustive]pub struct MacVerifyResponse {
pub name: String,
pub success: bool,
pub verified_data_crc32c: bool,
pub verified_mac_crc32c: bool,
pub verified_success_integrity: bool,
pub protection_level: ProtectionLevel,
/* private fields */
}Expand description
Response message for KeyManagementService.MacVerify.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe resource name of the CryptoKeyVersion used for verification. Check this field to verify that the intended resource was used for verification.
success: boolThis field indicates whether or not the verification operation for MacVerifyRequest.mac over MacVerifyRequest.data was successful.
verified_data_crc32c: boolIntegrity verification field. A flag indicating whether MacVerifyRequest.data_crc32c was received by KeyManagementService and used for the integrity verification of the data. A false value of this field indicates either that MacVerifyRequest.data_crc32c was left unset or that it was not delivered to KeyManagementService. If you’ve set MacVerifyRequest.data_crc32c but this field is still false, discard the response and perform a limited number of retries.
verified_mac_crc32c: boolIntegrity verification field. A flag indicating whether MacVerifyRequest.mac_crc32c was received by KeyManagementService and used for the integrity verification of the data. A false value of this field indicates either that MacVerifyRequest.mac_crc32c was left unset or that it was not delivered to KeyManagementService. If you’ve set MacVerifyRequest.mac_crc32c but this field is still false, discard the response and perform a limited number of retries.
verified_success_integrity: boolIntegrity verification field. This value is used for the integrity verification of [MacVerifyResponse.success]. If the value of this field contradicts the value of [MacVerifyResponse.success], discard the response and perform a limited number of retries.
protection_level: ProtectionLevelThe ProtectionLevel of the CryptoKeyVersion used for verification.
Implementations
Sourceimpl MacVerifyResponse
impl MacVerifyResponse
pub fn new() -> Self
Sourcepub fn set_success<T: Into<bool>>(self, v: T) -> Self
pub fn set_success<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_verified_data_crc32c<T: Into<bool>>(self, v: T) -> Self
pub fn set_verified_data_crc32c<T: Into<bool>>(self, v: T) -> Self
Sets the value of verified_data_crc32c.
Example
let x = MacVerifyResponse::new().set_verified_data_crc32c(true);Sourcepub fn set_verified_mac_crc32c<T: Into<bool>>(self, v: T) -> Self
pub fn set_verified_mac_crc32c<T: Into<bool>>(self, v: T) -> Self
Sets the value of verified_mac_crc32c.
Example
let x = MacVerifyResponse::new().set_verified_mac_crc32c(true);Sourcepub fn set_verified_success_integrity<T: Into<bool>>(self, v: T) -> Self
pub fn set_verified_success_integrity<T: Into<bool>>(self, v: T) -> Self
Sets the value of verified_success_integrity.
Example
let x = MacVerifyResponse::new().set_verified_success_integrity(true);Sourcepub fn set_protection_level<T: Into<ProtectionLevel>>(self, v: T) -> Self
pub fn set_protection_level<T: Into<ProtectionLevel>>(self, v: T) -> Self
Sets the value of protection_level.
Example
use google_cloud_kms_v1::model::ProtectionLevel;
let x0 = MacVerifyResponse::new().set_protection_level(ProtectionLevel::Software);
let x1 = MacVerifyResponse::new().set_protection_level(ProtectionLevel::Hsm);
let x2 = MacVerifyResponse::new().set_protection_level(ProtectionLevel::External);Trait Implementations
Sourceimpl Clone for MacVerifyResponse
impl Clone for MacVerifyResponse
Sourcefn clone(&self) -> MacVerifyResponse
fn clone(&self) -> MacVerifyResponse
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more