#[non_exhaustive]pub struct SingleTenantHsmInstance {
pub name: String,
pub create_time: Option<Timestamp>,
pub state: State,
pub quorum_auth: Option<QuorumAuth>,
pub delete_time: Option<Timestamp>,
pub unrefreshed_duration_until_disable: Option<Duration>,
pub disable_time: Option<Timestamp>,
/* private fields */
}Expand description
A SingleTenantHsmInstance represents a single-tenant HSM instance. It can be used for creating CryptoKeys with a ProtectionLevel of [HSM_SINGLE_TENANT][CryptoKeyVersion.ProtectionLevel.HSM_SINGLE_TENANT], as well as performing cryptographic operations using keys created within the SingleTenantHsmInstance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name for this
SingleTenantHsmInstance in
the format projects/*/locations/*/singleTenantHsmInstances/*.
create_time: Option<Timestamp>Output only. The time at which the SingleTenantHsmInstance was created.
state: StateOutput only. The state of the SingleTenantHsmInstance.
quorum_auth: Option<QuorumAuth>Required. The quorum auth configuration for the SingleTenantHsmInstance.
delete_time: Option<Timestamp>Output only. The time at which the SingleTenantHsmInstance was deleted.
unrefreshed_duration_until_disable: Option<Duration>Output only. The system-defined duration that an instance can remain unrefreshed until it is automatically disabled. This will have a value of 120 days.
disable_time: Option<Timestamp>Output only. The time at which the instance will be automatically disabled if not refreshed. This field is updated upon creation and after each successful refresh operation and enable. A [RefreshSingleTenantHsmInstance][] operation must be made via a SingleTenantHsmInstanceProposal before this time otherwise the SingleTenantHsmInstance will become disabled.
Implementations
Sourceimpl SingleTenantHsmInstance
impl SingleTenantHsmInstance
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = SingleTenantHsmInstance::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = SingleTenantHsmInstance::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = SingleTenantHsmInstance::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
use google_cloud_kms_v1::model::single_tenant_hsm_instance::State;
let x0 = SingleTenantHsmInstance::new().set_state(State::Creating);
let x1 = SingleTenantHsmInstance::new().set_state(State::PendingTwoFactorAuthRegistration);
let x2 = SingleTenantHsmInstance::new().set_state(State::Active);Sourcepub fn set_quorum_auth<T>(self, v: T) -> Selfwhere
T: Into<QuorumAuth>,
pub fn set_quorum_auth<T>(self, v: T) -> Selfwhere
T: Into<QuorumAuth>,
Sets the value of quorum_auth.
Example
use google_cloud_kms_v1::model::single_tenant_hsm_instance::QuorumAuth;
let x = SingleTenantHsmInstance::new().set_quorum_auth(QuorumAuth::default()/* use setters */);Sourcepub fn set_or_clear_quorum_auth<T>(self, v: Option<T>) -> Selfwhere
T: Into<QuorumAuth>,
pub fn set_or_clear_quorum_auth<T>(self, v: Option<T>) -> Selfwhere
T: Into<QuorumAuth>,
Sets or clears the value of quorum_auth.
Example
use google_cloud_kms_v1::model::single_tenant_hsm_instance::QuorumAuth;
let x = SingleTenantHsmInstance::new().set_or_clear_quorum_auth(Some(QuorumAuth::default()/* use setters */));
let x = SingleTenantHsmInstance::new().set_or_clear_quorum_auth(None::<QuorumAuth>);Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = SingleTenantHsmInstance::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = SingleTenantHsmInstance::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = SingleTenantHsmInstance::new().set_or_clear_delete_time(None::<Timestamp>);Sourcepub fn set_unrefreshed_duration_until_disable<T>(self, v: T) -> Self
pub fn set_unrefreshed_duration_until_disable<T>(self, v: T) -> Self
Sets the value of unrefreshed_duration_until_disable.
Example
use wkt::Duration;
let x = SingleTenantHsmInstance::new().set_unrefreshed_duration_until_disable(Duration::default()/* use setters */);Sourcepub fn set_or_clear_unrefreshed_duration_until_disable<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_unrefreshed_duration_until_disable<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of unrefreshed_duration_until_disable.
Example
use wkt::Duration;
let x = SingleTenantHsmInstance::new().set_or_clear_unrefreshed_duration_until_disable(Some(Duration::default()/* use setters */));
let x = SingleTenantHsmInstance::new().set_or_clear_unrefreshed_duration_until_disable(None::<Duration>);Sourcepub fn set_disable_time<T>(self, v: T) -> Self
pub fn set_disable_time<T>(self, v: T) -> Self
Sets the value of disable_time.
Example
use wkt::Timestamp;
let x = SingleTenantHsmInstance::new().set_disable_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_disable_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_disable_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of disable_time.
Example
use wkt::Timestamp;
let x = SingleTenantHsmInstance::new().set_or_clear_disable_time(Some(Timestamp::default()/* use setters */));
let x = SingleTenantHsmInstance::new().set_or_clear_disable_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for SingleTenantHsmInstance
impl Clone for SingleTenantHsmInstance
Sourcefn clone(&self) -> SingleTenantHsmInstance
fn clone(&self) -> SingleTenantHsmInstance
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more