#[non_exhaustive]pub struct UpdateCryptoKeyVersionRequest {
pub crypto_key_version: Option<CryptoKeyVersion>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for KeyManagementService.UpdateCryptoKeyVersion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.crypto_key_version: Option<CryptoKeyVersion>Required. CryptoKeyVersion with updated values.
update_mask: Option<FieldMask>Required. List of fields to be updated in this request.
Implementations
Sourceimpl UpdateCryptoKeyVersionRequest
impl UpdateCryptoKeyVersionRequest
pub fn new() -> Self
Sourcepub fn set_crypto_key_version<T>(self, v: T) -> Selfwhere
T: Into<CryptoKeyVersion>,
pub fn set_crypto_key_version<T>(self, v: T) -> Selfwhere
T: Into<CryptoKeyVersion>,
Sets the value of crypto_key_version.
Example
ⓘ
use google_cloud_kms_v1::model::CryptoKeyVersion;
let x = UpdateCryptoKeyVersionRequest::new().set_crypto_key_version(CryptoKeyVersion::default()/* use setters */);Sourcepub fn set_or_clear_crypto_key_version<T>(self, v: Option<T>) -> Selfwhere
T: Into<CryptoKeyVersion>,
pub fn set_or_clear_crypto_key_version<T>(self, v: Option<T>) -> Selfwhere
T: Into<CryptoKeyVersion>,
Sets or clears the value of crypto_key_version.
Example
ⓘ
use google_cloud_kms_v1::model::CryptoKeyVersion;
let x = UpdateCryptoKeyVersionRequest::new().set_or_clear_crypto_key_version(Some(CryptoKeyVersion::default()/* use setters */));
let x = UpdateCryptoKeyVersionRequest::new().set_or_clear_crypto_key_version(None::<CryptoKeyVersion>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCryptoKeyVersionRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCryptoKeyVersionRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateCryptoKeyVersionRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateCryptoKeyVersionRequest
impl Clone for UpdateCryptoKeyVersionRequest
Sourcefn clone(&self) -> UpdateCryptoKeyVersionRequest
fn clone(&self) -> UpdateCryptoKeyVersionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateCryptoKeyVersionRequest
impl Default for UpdateCryptoKeyVersionRequest
Sourcefn default() -> UpdateCryptoKeyVersionRequest
fn default() -> UpdateCryptoKeyVersionRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateCryptoKeyVersionRequest
impl PartialEq for UpdateCryptoKeyVersionRequest
Sourcefn eq(&self, other: &UpdateCryptoKeyVersionRequest) -> bool
fn eq(&self, other: &UpdateCryptoKeyVersionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateCryptoKeyVersionRequest