#[non_exhaustive]pub struct ServiceResolver {
pub service_directory_service: String,
pub endpoint_filter: String,
pub hostname: String,
pub server_certificates: Vec<Certificate>,
/* private fields */
}Expand description
A ServiceResolver represents an EKM replica that can be reached within an EkmConnection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_directory_service: StringRequired. The resource name of the Service Directory service pointing to
an EKM replica, in the format
projects/*/locations/*/namespaces/*/services/*.
endpoint_filter: StringOptional. The filter applied to the endpoints of the resolved service. If no filter is specified, all endpoints will be considered. An endpoint will be chosen arbitrarily from the filtered list for each request.
For endpoint filter syntax and examples, see https://cloud.google.com/service-directory/docs/reference/rpc/google.cloud.servicedirectory.v1#resolveservicerequest.
hostname: StringRequired. The hostname of the EKM replica used at TLS and HTTP layers.
server_certificates: Vec<Certificate>Required. A list of leaf server certificates used to authenticate HTTPS connections to the EKM replica. Currently, a maximum of 10 Certificate is supported.
Implementations
Sourceimpl ServiceResolver
impl ServiceResolver
pub fn new() -> Self
Sourcepub fn set_service_directory_service<T: Into<String>>(self, v: T) -> Self
pub fn set_service_directory_service<T: Into<String>>(self, v: T) -> Self
Sets the value of service_directory_service.
Example
let x = ServiceResolver::new().set_service_directory_service("example");Sourcepub fn set_endpoint_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_endpoint_filter<T: Into<String>>(self, v: T) -> Self
Sets the value of endpoint_filter.
Example
let x = ServiceResolver::new().set_endpoint_filter("example");Sourcepub fn set_hostname<T: Into<String>>(self, v: T) -> Self
pub fn set_hostname<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_server_certificates<T, V>(self, v: T) -> Self
pub fn set_server_certificates<T, V>(self, v: T) -> Self
Sets the value of server_certificates.
Example
use google_cloud_kms_v1::model::Certificate;
let x = ServiceResolver::new()
.set_server_certificates([
Certificate::default()/* use setters */,
Certificate::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for ServiceResolver
impl Clone for ServiceResolver
Sourcefn clone(&self) -> ServiceResolver
fn clone(&self) -> ServiceResolver
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more