#[non_exhaustive]pub struct AutokeyConfig {
pub name: String,
pub key_project: String,
pub state: State,
pub etag: String,
pub key_project_resolution_mode: KeyProjectResolutionMode,
/* private fields */
}Expand description
Cloud KMS Autokey configuration for a folder.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Name of the AutokeyConfig
resource, e.g. folders/{FOLDER_NUMBER}/autokeyConfig or
projects/{PROJECT_NUMBER}/autokeyConfig.
key_project: StringOptional. Name of the key project, e.g. projects/{PROJECT_ID} or
projects/{PROJECT_NUMBER}, where Cloud KMS Autokey will provision a new
CryptoKey when a
KeyHandle is created. On
UpdateAutokeyConfig,
the caller will require cloudkms.cryptoKeys.setIamPolicy permission on
this key project. Once configured, for Cloud KMS Autokey to function
properly, this key project must have the Cloud KMS API activated and the
Cloud KMS Service Agent for this key project must be granted the
cloudkms.admin role (or pertinent permissions). A request with an empty
key project field will clear the configuration.
state: StateOutput only. The state for the AutokeyConfig.
etag: StringOptional. A checksum computed by the server based on the value of other fields. This may be sent on update requests to ensure that the client has an up-to-date value before proceeding. The request will be rejected with an ABORTED error on a mismatched etag.
key_project_resolution_mode: KeyProjectResolutionModeOptional. KeyProjectResolutionMode for the AutokeyConfig.
Valid values are DEDICATED_KEY_PROJECT, RESOURCE_PROJECT, or
DISABLED.
Implementations
Sourceimpl AutokeyConfig
impl AutokeyConfig
pub fn new() -> Self
Sourcepub fn set_key_project<T: Into<String>>(self, v: T) -> Self
pub fn set_key_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_key_project_resolution_mode<T: Into<KeyProjectResolutionMode>>(
self,
v: T,
) -> Self
pub fn set_key_project_resolution_mode<T: Into<KeyProjectResolutionMode>>( self, v: T, ) -> Self
Sets the value of key_project_resolution_mode.
Example
use google_cloud_kms_v1::model::autokey_config::KeyProjectResolutionMode;
let x0 = AutokeyConfig::new().set_key_project_resolution_mode(KeyProjectResolutionMode::DedicatedKeyProject);
let x1 = AutokeyConfig::new().set_key_project_resolution_mode(KeyProjectResolutionMode::ResourceProject);
let x2 = AutokeyConfig::new().set_key_project_resolution_mode(KeyProjectResolutionMode::Disabled);Trait Implementations
Sourceimpl Clone for AutokeyConfig
impl Clone for AutokeyConfig
Sourcefn clone(&self) -> AutokeyConfig
fn clone(&self) -> AutokeyConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more