#[non_exhaustive]pub struct ExportTrustedKeyWrappedCryptoKeyVersionResponse {
pub wrapped_key: Bytes,
pub wrapped_key_crc32c: Option<Int64Value>,
/* private fields */
}Expand description
Response message for KeyManagementService.ExportTrustedKeyWrappedCryptoKeyVersion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wrapped_key: BytesThe wrapped key material.
wrapped_key_crc32c: Option<Int64Value>Integrity verification field. A CRC32C checksum of the returned ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key. An integrity check of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key can be performed by computing the CRC32C checksum of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type.
Implementations
Sourceimpl ExportTrustedKeyWrappedCryptoKeyVersionResponse
impl ExportTrustedKeyWrappedCryptoKeyVersionResponse
Sourcepub fn set_wrapped_key<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_wrapped_key<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of wrapped_key.
Example
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_wrapped_key(bytes::Bytes::from_static(b"example"));Sourcepub fn set_wrapped_key_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
pub fn set_wrapped_key_crc32c<T>(self, v: T) -> Selfwhere
T: Into<Int64Value>,
Sets the value of wrapped_key_crc32c.
Example
use wkt::Int64Value;
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_wrapped_key_crc32c(Int64Value::default()/* use setters */);Sourcepub fn set_or_clear_wrapped_key_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
pub fn set_or_clear_wrapped_key_crc32c<T>(self, v: Option<T>) -> Selfwhere
T: Into<Int64Value>,
Sets or clears the value of wrapped_key_crc32c.
Example
use wkt::Int64Value;
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_or_clear_wrapped_key_crc32c(Some(Int64Value::default()/* use setters */));
let x = ExportTrustedKeyWrappedCryptoKeyVersionResponse::new().set_or_clear_wrapped_key_crc32c(None::<Int64Value>);Trait Implementations
Sourceimpl Clone for ExportTrustedKeyWrappedCryptoKeyVersionResponse
impl Clone for ExportTrustedKeyWrappedCryptoKeyVersionResponse
Sourcefn clone(&self) -> ExportTrustedKeyWrappedCryptoKeyVersionResponse
fn clone(&self) -> ExportTrustedKeyWrappedCryptoKeyVersionResponse
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ExportTrustedKeyWrappedCryptoKeyVersionResponse
impl Default for ExportTrustedKeyWrappedCryptoKeyVersionResponse
Sourcefn default() -> ExportTrustedKeyWrappedCryptoKeyVersionResponse
fn default() -> ExportTrustedKeyWrappedCryptoKeyVersionResponse
impl StructuralPartialEq for ExportTrustedKeyWrappedCryptoKeyVersionResponse