#[non_exhaustive]pub struct ImportTrustedKeyWrappedCryptoKeyVersionRequest {
pub parent: String,
pub importing_key: String,
pub crypto_key_version: String,
pub wrapped_key: Bytes,
pub algorithm: CryptoKeyVersionAlgorithm,
/* private fields */
}Expand description
Request message for KeyManagementService.ImportTrustedKeyWrappedCryptoKeyVersion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: Stringimporting_key: StringRequired. Required - the CKV of the trusted key used to import. This can be the name of a CryptoKeyVersion or a CryptoKey.
crypto_key_version: StringOptional. The optional name of an existing CryptoKeyVersion to target for an import operation. If this field is not present, a new CryptoKeyVersion containing the supplied key material is created.
If this field is present, the supplied key material is imported into the existing CryptoKeyVersion. To import into an existing CryptoKeyVersion, the CryptoKeyVersion must be a child of ImportTrustedKeyWrappedCryptoKeyVersionRequest.parent, have been previously created via ImportTrustedKeyWrappedCryptoKeyVersion, and be in DESTROYED or IMPORT_FAILED state. The key material and algorithm must match the previous CryptoKeyVersion exactly if the CryptoKeyVersion has ever contained key material
wrapped_key: BytesRequired. The target key pre-wrapped on premises.
algorithm: CryptoKeyVersionAlgorithmRequired. Required - The algorithm of the key being imported. This does not need to match the version_template of the CryptoKey this version imports into.
Implementations
Sourceimpl ImportTrustedKeyWrappedCryptoKeyVersionRequest
impl ImportTrustedKeyWrappedCryptoKeyVersionRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_importing_key<T: Into<String>>(self, v: T) -> Self
pub fn set_importing_key<T: Into<String>>(self, v: T) -> Self
Sets the value of importing_key.
Example
let x = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_importing_key("example");Sourcepub fn set_crypto_key_version<T: Into<String>>(self, v: T) -> Self
pub fn set_crypto_key_version<T: Into<String>>(self, v: T) -> Self
Sets the value of crypto_key_version.
Example
let x = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_crypto_key_version("example");Sourcepub fn set_wrapped_key<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_wrapped_key<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of wrapped_key.
Example
let x = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_wrapped_key(bytes::Bytes::from_static(b"example"));Sourcepub fn set_algorithm<T: Into<CryptoKeyVersionAlgorithm>>(self, v: T) -> Self
pub fn set_algorithm<T: Into<CryptoKeyVersionAlgorithm>>(self, v: T) -> Self
Sets the value of algorithm.
Example
use google_cloud_kms_v1::model::crypto_key_version::CryptoKeyVersionAlgorithm;
let x0 = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_algorithm(CryptoKeyVersionAlgorithm::GoogleSymmetricEncryption);
let x1 = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_algorithm(CryptoKeyVersionAlgorithm::Aes128Gcm);
let x2 = ImportTrustedKeyWrappedCryptoKeyVersionRequest::new().set_algorithm(CryptoKeyVersionAlgorithm::Aes256Gcm);Trait Implementations
Sourceimpl Clone for ImportTrustedKeyWrappedCryptoKeyVersionRequest
impl Clone for ImportTrustedKeyWrappedCryptoKeyVersionRequest
Sourcefn clone(&self) -> ImportTrustedKeyWrappedCryptoKeyVersionRequest
fn clone(&self) -> ImportTrustedKeyWrappedCryptoKeyVersionRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ImportTrustedKeyWrappedCryptoKeyVersionRequest
impl Default for ImportTrustedKeyWrappedCryptoKeyVersionRequest
Sourcefn default() -> ImportTrustedKeyWrappedCryptoKeyVersionRequest
fn default() -> ImportTrustedKeyWrappedCryptoKeyVersionRequest
impl StructuralPartialEq for ImportTrustedKeyWrappedCryptoKeyVersionRequest