#[non_exhaustive]pub struct KeyHandle {
pub name: String,
pub kms_key: String,
pub resource_type_selector: String,
/* private fields */
}Expand description
Resource-oriented representation of a request to Cloud KMS Autokey and the resulting provisioning of a CryptoKey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. Name of the KeyHandle
resource, e.g.
projects/{PROJECT_ID}/locations/{LOCATION}/keyHandles/{KEY_HANDLE_ID}.
kms_key: StringOutput only. Name of a CryptoKey that has been provisioned for Customer Managed Encryption Key (CMEK) use in the KeyHandle project and location for the requested resource type. The CryptoKey project will reflect the value configured in the AutokeyConfig on the resource project’s ancestor folder at the time of the KeyHandle creation. If more than one ancestor folder has a configured AutokeyConfig, the nearest of these configurations is used.
resource_type_selector: StringRequired. Indicates the resource type that the resulting
CryptoKey is meant to protect, e.g.
{SERVICE}.googleapis.com/{TYPE}. See documentation for supported resource
types.
Implementations
Sourceimpl KeyHandle
impl KeyHandle
pub fn new() -> Self
Sourcepub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_resource_type_selector<T: Into<String>>(self, v: T) -> Self
pub fn set_resource_type_selector<T: Into<String>>(self, v: T) -> Self
Sets the value of resource_type_selector.
Example
let x = KeyHandle::new().set_resource_type_selector("example");