#[non_exhaustive]pub struct ListCryptoKeysRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub version_view: CryptoKeyVersionView,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request message for KeyManagementService.ListCryptoKeys.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the KeyRing
to list, in the format projects/*/locations/*/keyRings/*.
page_size: i32Optional. Optional limit on the number of CryptoKeys to include in the response. Further CryptoKeys can subsequently be obtained by including the ListCryptoKeysResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.
page_token: StringOptional. Optional pagination token, returned earlier via ListCryptoKeysResponse.next_page_token.
version_view: CryptoKeyVersionViewThe fields of the primary version to include in the response.
filter: StringOptional. Only include resources that match the filter in the response. For more information, see Sorting and filtering list results.
order_by: StringOptional. Specify how the results should be sorted. If not specified, the results will be sorted in the default order. For more information, see Sorting and filtering list results.
Implementations
Sourceimpl ListCryptoKeysRequest
impl ListCryptoKeysRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListCryptoKeysRequest::new().set_page_token("example");Sourcepub fn set_version_view<T: Into<CryptoKeyVersionView>>(self, v: T) -> Self
pub fn set_version_view<T: Into<CryptoKeyVersionView>>(self, v: T) -> Self
Sets the value of version_view.
Example
use google_cloud_kms_v1::model::crypto_key_version::CryptoKeyVersionView;
let x0 = ListCryptoKeysRequest::new().set_version_view(CryptoKeyVersionView::Full);Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self