ListKeyHandlesRequest

Struct ListKeyHandlesRequest 

#[non_exhaustive]
pub struct ListKeyHandlesRequest { pub parent: String, pub page_size: i32, pub page_token: String, pub filter: String, /* private fields */ }
Request message for Autokey.ListKeyHandles.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. Name of the resource project and location from which to list KeyHandles, e.g. projects/{PROJECT_ID}/locations/{LOCATION}.

page_size: i32

Optional. Optional limit on the number of KeyHandles to include in the response. The service may return fewer than this value. Further KeyHandles can subsequently be obtained by including the ListKeyHandlesResponse.next_page_token in a subsequent request. If unspecified, at most 100 KeyHandles will be returned.

page_token: String

Optional. Optional pagination token, returned earlier via ListKeyHandlesResponse.next_page_token.

filter: String

Optional. Filter to apply when listing KeyHandles, e.g. resource_type_selector="{SERVICE}.googleapis.com/{TYPE}".

Implementations

Source

impl ListKeyHandlesRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListKeyHandlesRequest::new().set_parent("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListKeyHandlesRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListKeyHandlesRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListKeyHandlesRequest::new().set_filter("example");