#[non_exhaustive]pub struct RetiredResource {
pub name: String,
pub original_resource: String,
pub resource_type: String,
pub delete_time: Option<Timestamp>,
/* private fields */
}Expand description
A RetiredResource resource represents the record of a deleted CryptoKey. Its purpose is to provide visibility into retained user data and to prevent reuse of these names for new CryptoKeys.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The resource name for this
RetiredResource in the format
projects/*/locations/*/retiredResources/*.
original_resource: StringOutput only. The full resource name of the original
CryptoKey that was deleted in the format
projects/*/locations/*/keyRings/*/cryptoKeys/*.
resource_type: StringOutput only. The resource type of the original deleted resource.
delete_time: Option<Timestamp>Output only. The time at which the original resource was deleted and this RetiredResource record was created.
Implementations
Sourceimpl RetiredResource
impl RetiredResource
Sourcepub fn set_original_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_original_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of original_resource.
Example
let x = RetiredResource::new().set_original_resource("example");Sourcepub fn set_resource_type<T: Into<String>>(self, v: T) -> Self
pub fn set_resource_type<T: Into<String>>(self, v: T) -> Self
Sets the value of resource_type.
Example
let x = RetiredResource::new().set_resource_type("example");Sourcepub fn set_delete_time<T>(self, v: T) -> Self
pub fn set_delete_time<T>(self, v: T) -> Self
Sets the value of delete_time.
Example
use wkt::Timestamp;
let x = RetiredResource::new().set_delete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of delete_time.
Example
use wkt::Timestamp;
let x = RetiredResource::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = RetiredResource::new().set_or_clear_delete_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for RetiredResource
impl Clone for RetiredResource
Sourcefn clone(&self) -> RetiredResource
fn clone(&self) -> RetiredResource
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RetiredResource
impl Debug for RetiredResource
Sourceimpl Default for RetiredResource
impl Default for RetiredResource
Sourcefn default() -> RetiredResource
fn default() -> RetiredResource
Sourceimpl Message for RetiredResource
impl Message for RetiredResource
Sourceimpl PartialEq for RetiredResource
impl PartialEq for RetiredResource
impl StructuralPartialEq for RetiredResource